yap

package module
v0.0.0-...-34ff358 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: AGPL-3.0 Imports: 13 Imported by: 0

README

go-yap

Go version of yap

Warning

This project was in the middle of a major overhaul before committing it.

legacy exists to keep a drop in replacement to how it was used previously and will be deprecated eventually

Documentation

Index

Constants

const (
	INSERT_SPACES_IN_WEBSOCKET int = 1 << iota
	INSERT_SPACES_IN_FILE
	INSERT_SPACES_IN_TERMINAL
)

Variables

var ClientJS []byte
var NL = &shared_newline{}

Functions

func Blue

func Blue(input any) *colored

func Cyan

func Cyan(input any) *colored

func Gray

func Gray(input any) *colored

func Green

func Green(input any) *colored

func Huge

func Huge(k int, v any) *sized

func Magenta

func Magenta(input any) *colored

func New

func New(logfile, terminal io.Writer, default_keep, poll_interval_ms int, flags int) *impl

func NoSpaceAfter

func NoSpaceAfter(v any) *no_space_after

func Red

func Red(input any) *colored

func ServeClientJS

func ServeClientJS(w http.ResponseWriter, r *http.Request)

func White

func White(input any) *colored

func Yellow

func Yellow(input any) *colored

Types

type HTML_PAIR

type HTML_PAIR struct {
	Data    string
	Sibling ulid.ULID
}

func (HTML_PAIR) MarshalJSON

func (pair HTML_PAIR) MarshalJSON() ([]byte, error)

type HTML_PART

type HTML_PART string

type HTML_SHORT

type HTML_SHORT string

Directories

Path Synopsis
cmd
go_yap_demo command

Jump to